/*
 * This file is a part of CMSLU -- Content Management System like Unix
 * and is not publicly distributed
 * 
 * Copyright (c) 2008-2009, Tomasz Sowa
 * All rights reserved.
 * 
 */
 
#include "content.h"
#include "../core/request.h"
#include "../core/error.h"
#include "../core/db.h"
#include "../core/mount.h"
#include "../core/data.h"




bool Content::FunCreateThreadCheckAccess()
{
	if( !request.CanCreateThread() )
	{
		request.status = Error::permission_denied;
		return false;
	}


return true;
}



bool Content::FunCreateThreadCheckAbuse()
{
	if( !CheckRebus() )
	{
		request.status = Error::incorrect_rebus;
		request.session->done = Done::added_thread;
		request.session->done_status = Error::incorrect_rebus;
		
		return false;
	}

	CheckGetPostTimes();

	if( request.session->spam_score > 0 )
	{
		request.status = Error::spam;
		request.session->done = Done::added_thread;
		request.session->done_status = Error::spam;
		
		log << log1 << "Content: ignoring due to suspected spamming" << logend;
		return false;
	}

return true;
}



void Content::ReadThread(Thread & thread)
{
	thread.parent_id = request.dir_table.back()->id;
}



void Content::AddThread()
{
	request.thread.dir_id    = request.dir_table.back()->id;
	request.thread.closed    = false;
	request.thread.items     = 1;
	request.thread.last_item = request.item; // set by PostFunEmacsAdd()

	request.session->done_status = db.AddThread(request.thread);
}



void Content::PostFunCreateThreadLogAndRedirect()
{
	if( request.session->done_status == Error::ok )
	{
		request.session->done = Done::added_thread;

		log << log2 << "Content: added a new thread" << logend;
		RedirectToLastDir();
	}
	else
	{
		log << log1 << "Content: problem with adding a new thread, error code:"
			<< request.session->done_status << logend;
	}
}



void Content::PostFunCreateThread()
{
	if( !FunCreateThreadCheckAccess() )
		return;

	ReadItem(request.item, Item::dir);
	ReadThread(request.thread);
	request.item.privileges = 0777; // !! tymczasowo 777 aby wszyscy mogli wysylac posty

	if( !FunCreateThreadCheckAbuse() )
	{
		ReadItemContentWithType(request.item); // for correctly displaying the form
		return;
	}

	Mkdir(request.item, true);
	
	if( request.session->done_status == Error::ok )
	{
		ReadItemContentWithType(request.item);
		request.item.type = Item::file;
		request.item.privileges = 0644; // !! tymczasowo
		request.item.parent_id = request.dir_table.back()->id;
		PostFunEmacsAdd();

		if( request.session->done_status == Error::ok )
			AddThread();
	}

	PostFunCreateThreadLogAndRedirect();
}







void Content::FunCreateThread()
{
	FunCreateThreadCheckAccess();
}




